@@ -4,8 +4,8 @@ var Log = require('grunt-legacy-log').Log;
 var assert = require('assert');
 var through = require('through2');
 
-module.exports = function(grunt) {
-  grunt.file.setBase('../fixtures/load-npm-tasks');
+function test(grunt, fixture) {
+  grunt.file.setBase('../fixtures/' + fixture);
 
   // Create a custom log to assert output
   var stdout = [];
@@ -39,4 +39,11 @@ module.exports = function(grunt) {
       throw err;
     }
   });
+}
+
+module.exports = function(grunt) {
+  // NPM task package is inside $CWD/node_modules
+  test(grunt, 'load-npm-tasks');
+  // NPM task package hoisted to $CWD/../node_modules
+  test(grunt, 'load-npm-tasks/test-package');
 };
